pub fn read() -> ProcFsXfsStatExpand description
The main function for building a [ProcMemInfo] struct with current data.
This uses the Builder pattern, which allows settings such as the filename to specified.
pub fn read() -> ProcFsXfsStatThe main function for building a [ProcMemInfo] struct with current data.
This uses the Builder pattern, which allows settings such as the filename to specified.