pub struct CpuStat {
    pub name: String,
    pub user: u64,
    pub nice: u64,
    pub system: u64,
    pub idle: u64,
    pub iowait: Option<u64>,
    pub irq: Option<u64>,
    pub softirq: Option<u64>,
    pub steal: Option<u64>,
    pub guest: Option<u64>,
    pub guest_nice: Option<u64>,
}
Struct for holding cpu times in milliseconds

Fields

name: String

cpu name. ‘cpu’ means total of all cpus, cpuN means individual cpu

user: u64

user time in milliseconds

nice: u64

user time reniced in milliseconds

system: u64

system/kernel time in milliseconds

idle: u64

idle time in milliseconds

iowait: Option<u64>

idle time in milliseconds attributed to performing IO

irq: Option<u64>

irq time in milliseconds

softirq: Option<u64>

softirq time in milliseconds

steal: Option<u64>

steal time in milliseconds Introduced with kernel version 2.6.11

guest: Option<u64>

guest user time in milliseconds Introduced with kernel version 2.6.24

guest_nice: Option<u64>

guest user time reniced in milliseconds Introduced with kernel version 2.6.24

Implementations

source

impl CpuStat

source

pub fn generate_cpu_times(proc_stat_cpu_line: &str) -> CpuStat